#! /usr/bin/perl
use strict;
use Getopt::Std;

my %opts;
getopts( 'hcsn', \%opts );
if ( $opts{ 'h' } ) { usage(); }

#my $pkgdir = "/usr/local/anlcron/bgp_mon";
#my $outdir = "/usr/www/sites/mren/bgp";
#my $target = "lsd6509";
#my $local_name = "MREN";

my $pkgdir = shift(@ARGV);
my $target = shift(@ARGV);
my $local_name = shift(@ARGV);
my $change_threshold = shift(@ARGV);




my $tmpdir="$pkgdir/tmp/$target";

my $notify = join( " ", @ARGV ); 

if ( ! $notify ){ usage(); }
my $count_file = "$tmpdir/route_counts.txt";
my $last_count_file = "$tmpdir/route_counts.txt.last";

my %OLD_COUNTS;
my %OLD_STATUS;

open ( FILE, $last_count_file ) || die "could not open $last_count_file\n";
while (my $line = <FILE> )
{
	chomp($line);
	$line =~ s/^\s*//g;
	$line =~ s/\s*$//g;
	if ( $line =~ /^$/ || $line =~ /^#/ ) { next; }
	my ( $time, $peer, $count, $status, $as, $as_name ) = split( " ", $line, 6 );
	$OLD_COUNTS{ $peer } = $count;
	$OLD_STATUS{ $peer } = $status;
}
close(FILE);

my @output;
my @status_output;

open ( FILE, $count_file ) || die "could not open $count_file\n";
while (my $line = <FILE> )
{
	chomp($line);
	$line =~ s/^\s*//g;
	$line =~ s/\s*$//g;
	if ( $line =~ /^$/ || $line =~ /^#/ ) { next; }
	my ( $time, $peer, $count, $status, $as, $as_name ) = split( " ", $line, 6 );
        my $diff = $count - $OLD_COUNTS{ $peer };
	my $percnt_change;
	if ( $OLD_COUNTS{ $peer } == 0 )
	{
		if ( $diff != 0 )
		{
			$percnt_change = $change_threshold;
		}
	}
	else
	{
		$percnt_change = $diff / $OLD_COUNTS{ $peer };
		$percnt_change = $percnt_change * 100;
	}
        if ( $percnt_change >= $change_threshold || $percnt_change <= (-1 * $change_threshold ) )
        {
                push (@output, "$peer (AS $as - $as_name) Route Count Changed from $OLD_COUNTS{ $peer } to $count!" );
        }
	if ( $status ne $OLD_STATUS{ $peer } )
	{
		if ( ($status ne "" && $OLD_STATUS{ $peer } ne "") || ! $opts{ 'n' } )
		{
                	push (@status_output, "$local_name - $target BGP Peer $peer (AS $as - $as_name) Status Changed from $OLD_STATUS{ $peer } to $status!" );
		}
	}

}
close(FILE);


if ( ! $opts{ 'c' } && $output[0] ne "" )
{
	open( CMD, "| mailx -s \"$local_name - $target BGP Peering Route Count Changes\" $notify" ) || die "failed to open mailx -s \"Route Count Changes\" $notify\n";
	foreach my $line (@output)
	{
		print CMD "$line\n\n";
		#print "$line\n\n";
	}
	close(CMD);
}

if ( ! $opts{ 's' } && $status_output[0] ne "" )
{
	open( CMD, "| mailx -s \"$local_name - $target BGP Peering Status Changes\" $notify" ) || die "failed to open mailx -s \"Route Status Changes\" $notify\n";
	foreach my $line (@status_output)
	{
		print CMD "$line\n\n";
		#print "$line\n\n";
	}
	close(CMD);
}

sub usage
{
	print "usage: $0 [-hcs] pkgdir target local_name change_threshold email_addr [email_addr ...]\n";
	print "compares pkgdir/tmp/target/route_counts.txt to pkgdir/tmp/target/route_counts.txt.last\n";
	print "and sends email alerts to email_addr if any of the route counts have changes by more than\n";
	print "change_threshold % or if the status of any of the bgp sessions has changed\n";
	print "options:\n";
	print "-h = print this message\n";
	print "-c = do not send messages for route count changes\n";
	print "-s = do not send messages for bgp status changes\n";
	print "-n = do not send messages for bgp status changes if new or old status is empty string (maybe previous run failed)\n";
	exit 2;
}
