#! /bin/sh
PKGDIR=/usr/local/bgp_mon
OUTDIR=/usr/www/docs/bgp_mon
BINDIR=$PKGDIR/bin
PATH="/usr/bin:/bin:$PATH"
export PATH


# SNMP Read community
COMMUNITY="public"

# percentage change in number of routes from a peer that triggers an alert
CHANGE_THRESHOLD=10

# name of local AS
LOCAL_NAME="My Own AS"

# Space seperated list of targets to hit query
TARGETS="router1 router2"

# Space seperated list of email addresses to send status and route count changes to
NOTIFY="me@myas.com"



USAGE="usage: $0 [target ...]\nruns several sub-scripts to collect bgp peering data from either target or a built in list of targets ($TARGETS), graph this data, and send email alerts on bgp status or route count changes\n"

test "$1" = "-h" && printf "$USAGE" && exit 2

# command line overide of targets list
test -z "$1" || TARGETS="$*"

for target in $TARGETS
do
	test -d "$OUTDIR/$target" || mkdir -p "$OUTDIR/$target"
	test -d "$PKGDIR/tmp/$target" || mkdir -p "$PKGDIR/tmp/$target"
	test -d "$PKGDIR/rrds/$target" || mkdir -p "$PKGDIR/rrds/$target"

	$BINDIR/bgp_data_collector.pl "$PKGDIR" "$OUTDIR" "$target" "$COMMUNITY" "$LOCAL_NAME"
	$BINDIR/update_bgp_route_count_rrds.sh "$PKGDIR" "$OUTDIR" "$target"
	$BINDIR/bgp_alerter.pl -n -c "$PKGDIR" "$target" "$LOCAL_NAME" "$CHANGE_THRESHOLD" "$NOTIFY"
done
